@@ -240,6 +240,11 @@ class TDA():
 
         objectName = objectName.replace("\\", "/")
 
+        specialCharList = [";", "'", '"']
+        for specialChar in specialCharList:
+            if specialChar in filepath:
+                raise Exception(f"filepath can not contained a special chars {specialCharList}")
+
         file = File(filepath, objectName.strip("/"), self.filePrefix, self.dataset.endpoint, self.dataset.datasetType)
         self.fileList.append(file)
         if self.debug:
@@ -440,7 +445,7 @@ class TDA():
                 syncData = []
 
 
-        if len(syncData) >= 0:#最后几个没同步的数据
+        if len(syncData) > 0:#最后几个没同步的数据
             info = self.dataset.SyncDataToWeb(syncData)
             if self.debug:
                 print(f"[UPLOAD_FILES] sync data to server, success:{info['succ']}, fail:{info['fail']}")
